@@ -492,7 +492,7 @@ fn emit_field_write(
             if (!(#v)) {
                 // assertion is false, raise error
                 return Err(::#crate_::DekuError::Assertion(format!(
-                            "field '{}' failed assertion: {}",
+                            "field {} failed assertion: {}",
                             #field_ident_str,
                             stringify!(#v)
                         )));
@@ -507,7 +507,7 @@ fn emit_field_write(
             if (!(*(#field_ident) == (#v))) {
                 // assertion is false, raise error
                 return Err(::#crate_::DekuError::Assertion(format!(
-                            "field '{}' failed assertion: {}",
+                            "field {} failed assertion: {}",
                             #field_ident_str,
                             stringify!(#field_ident == #v)
                         )));
